package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.service.ITmstruckWeightResultService;

import com.steerinfo.dil.service.impl.TmstruckWeightResultServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * TmstruckWeightResult RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-09 02:21
 * 类描述
 * 修订历史：
 * 日期：2021-09-09
 * 作者：generator
 * 参考：
 * 描述：TmstruckWeightResult RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/tmstruckweightresults")
public class TmstruckWeightResultController extends BaseRESTfulController {

    @Autowired
    TmstruckWeightResultServiceImpl tmstruckWeightResultService;

    @Autowired
    ESFeign esFeign;

    @Autowired
    ColumnDataUtil columnDataUtil;



    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    @ApiOperation(value="新增计量实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "总实绩ID、计皮点、计毛点", required = false, dataType = "Map"),
    })
    @PostMapping("/addWeightResult")
    public RESTfulResult addWeightResult(@RequestBody Map<String, Object> mapValue){
        int i = tmstruckWeightResultService.addWeightResult(mapValue);
        return success(i);
    }


    @ApiOperation(value="查询计毛实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(102)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllJiMaoResult")
    public RESTfulResult getAllJiMaoResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer orderType,
                                               String con,
                                               String userId,
                                               String usersId,
                                               String startTime,
                                               String endTime

    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if (orderType!=null) {
            mapValue.put("orderTypee", orderType);
        }
        if (con!=null&&!"null".equals(con)){
            mapValue.put("con",con);
        }
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (usersId!=null){
            mapValue.put("usersId",usersId);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum,pageSize);
        //分页数据
        List<Map<String, Object>> jiMaoResult = tmstruckWeightResultService.getAllJiMaoResult(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,jiMaoResult);
        return success(pageList);
    }


    @ApiOperation(value="查询计皮实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(104)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllJiPiResult")
    public RESTfulResult getAllJiPiResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer orderType,
                                           String con,
                                           String userId,
                                           String userIds,
                                          String startTime,
                                          String endTime
    ){

        if (orderType!=null) {
            mapValue.put("orderTypee", orderType);
        }
        if (con!=null&&!"null".equals(con)){
            mapValue.put("con",con);
        }
        if (userId!=null) {
            mapValue.put("userId",userId);
        }
        if (userIds!=null) {
            mapValue.put("usersId", userIds);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum,pageSize);
        //分页数据
        List<Map<String, Object>> jiPiResult = tmstruckWeightResultService.getAllJiPiResult(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,jiPiResult);
        return success(pageList);
    }


    /**
     *通过运输订单判断下一步是否需要计量,更新汽车衡到计量实绩中
     */
    @PostMapping("/updateTruckCalculate/{orderId}")
    public RESTfulResult updateTruckCalculate(@PathVariable("orderId") Integer orderId){
        int i =0;
        return  success(i);
    }

    @PostMapping("/update")
    public RESTfulResult update(@RequestBody(required = false) Map<String, Object> map){
        try {
            tmstruckWeightResultService.updateSteelTruckWeightResult(map);
        } catch (Exception e) {
            e.printStackTrace();
            return failed();
        }
        return  success();
    }
}

  
