package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.TmstruckEnfactoryResultMapper;
import com.steerinfo.dil.mapper.TmstruckLeaveFactoryResultMapper;
import com.steerinfo.dil.service.ITmstruckSelfMachineService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-11-17 20:59
 */
@Service
public class TmstruckSelfMachineService implements ITmstruckSelfMachineService {

    @Autowired
    TmstruckEnfactoryResultMapper tmstruckEnfactoryResultMapper;

    @Autowired
    TmstruckLeaveFactoryResultMapper tmstruckLeaveFactoryResultMapper;

    /**
     * 提货单信息
     * @param orderNumber
     * @return
     */
    @Override
    public Map<String, Object> getBillOrder(String orderNumber) {
        //1.根据运输订单号查询主干信息
        Map<String,Object>map=tmstruckEnfactoryResultMapper.getBillOrder(orderNumber);
        if(map !=null){
            //2.根据运输订单号查询枝叶信息-物资
            List<Map<String,Object>>list=tmstruckEnfactoryResultMapper.getBillOrderMaterial(orderNumber);
            map.put("materialList",list);
        }
        return map;
    }

    @Override
    public Map<String, Object> getDeliveryOrder(String orderNumber) {
        //1.根据运输订单号查询主干信息
        Map<String,Object> map = tmstruckLeaveFactoryResultMapper.getDeliveryOrder(orderNumber);
        map.put("orderNumber",orderNumber);
        if(map !=null){
            List<Map<String, Object>> deliveryOrderMaterialList = tmstruckLeaveFactoryResultMapper.getDeliveryOrderMaterial(orderNumber);
            //判断为棒材还是线材
            for (Map<String,Object> map1:deliveryOrderMaterialList){
                map1.remove("materialWeight");
                String materialName =(String) map1.get("materialName");
                map.put("materialName",materialName);
                //判断是否为盘螺
                if (materialName.contains("盘螺")){
                    //根据运输订单号查找实绩重量
                    Map<String, Object> netWeight = tmstruckLeaveFactoryResultMapper.getNetWeightByOrder(map);
                    String nowNetWeight =(String) netWeight.get("nowNetWeight");
                    if (nowNetWeight!=null) {
                        map.put("materialWeight", nowNetWeight);
                    }
                }else {
                    //获取物资理重
                    String theoryWeight = tmstruckLeaveFactoryResultMapper.getTheoryWeight(map);
                    map.put("materialWeight",theoryWeight);
                }
            }
            map.put("deliveryOrderMaterialList",deliveryOrderMaterialList);
        }
        return map;
    }
}
